@@ -7,7 +7,7 @@
     :license: LGPL – see license.lgpl for more details.
 '''
 
-from pyca.utils import timestamp, try_mkdir, configure_service, terminate
+from pyca.utils import timestamp, try_mkdir, terminate
 from pyca.utils import set_service_status, set_service_status_immediate
 from pyca.utils import recording_state, update_event_status
 from pyca.config import config
@@ -89,12 +89,14 @@ def safe_start_capture(event):
     try:
         start_capture(event)
     except Exception:
-        logger.error('Recording failed')
-        logger.error(traceback.format_exc())
-        # Update state
-        recording_state(event.uid, 'capture_error')
-        update_event_status(event, Status.FAILED_RECORDING)
-        set_service_status_immediate(Service.CAPTURE, ServiceStatus.IDLE)
+        logger.exception('Recording failed')
+        # Update current status in Opencast
+        try:
+            set_service_status_immediate(Service.CAPTURE, ServiceStatus.IDLE)
+            recording_state(event.uid, 'capture_error')
+            update_event_status(event, Status.FAILED_RECORDING)
+        except Exception:
+            logger.exception('Could not update recording status')
 
 
 def recording_command(event):
@@ -207,5 +209,4 @@ def run():
     '''Start the capture agent.
     '''
     signal.signal(signal.SIGTERM, sigterm_handler)
-    configure_service('capture.admin')
     control_loop()
