@@ -34,6 +34,9 @@ sigterm_time     = integer(min=-1, default=-1)
 sigkill_time     = integer(min=-1, default=120)
 exit_code        = integer(min=0, max=255, default=0)
 
+[ingest]
+delete_after_upload = boolean(default=false)
+
 [server]
 url              = string(default='https://develop.opencast.org')
 auth_method      = option('basic', 'digest', default='digest')
@@ -47,6 +50,7 @@ username         = string(default='admin')
 password         = string(default='opencast')
 refresh_rate     = integer(min=1, default=10)
 url              = string(default='http://localhost:5000')
+log_command      = string(default='')
 
 [logging]
 syslog           = boolean(default=False)
@@ -54,6 +58,8 @@ stderr           = boolean(default=True)
 file             = string(default='')
 level            = option('debug', 'info', 'warning', 'error', default='info')
 format           = string(default='[%(name)s:%(lineno)s:%(funcName)s()] [%(levelname)s] %(message)s')
+
+[services]
 '''  # noqa
 
 cfgspec = __CFG.split('\n')
@@ -121,7 +127,11 @@ def config(*args):
 
     :param key: optional configuration key to return
     :type key: string
-    :return: dictionary containing the configuration or configuration value
+    :return: Part of the configuration object containing the configuration
+             or configuration value.
+             If a part of the configuration object (e.g. configobj.Section) is
+             returned, it can be treated like a dictionary.
+             Returning None, if the configuration value is not found.
     '''
     cfg = __config or update_configuration()
     for key in args:
